@@ -14,10 +14,10 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-use crate::types::Move;
-
 use arrayvec::ArrayVec;
 
+use crate::types::Move;
+
 /// A container for moves that can be stored inline on the stack.
 ///
 /// The capacity is limited, but there is enough space to hold the legal
@@ -34,9 +34,16 @@ use arrayvec::ArrayVec;
 /// moves.retain(|m| m.role() == Role::Pawn);
 /// assert_eq!(moves.len(), 16);
 /// ```
-pub type MoveList = ArrayVec<Move, {
-    #[cfg(feature = "variant")]
-    { 512 }
-    #[cfg(not(feature = "variant"))]
-    { 256 }
-}>;
+pub type MoveList = ArrayVec<
+    Move,
+    {
+        #[cfg(feature = "variant")]
+        {
+            512
+        }
+        #[cfg(not(feature = "variant"))]
+        {
+            256
+        }
+    },
+>;
